# nr.pylang.utils

Utilities for Python constructs (class and function definitions, exception
handling, modules and type annotations).

__Note__: `typing` is an optional dependency and is thus not listed in the
requirements for this package.
